VarScope

Struct VarScope 

pub struct VarScope { /* private fields */ }
Mapping of variable names to indices inside a scope (e.g. a rule or a query).

Implementations

Source

impl VarScope

pub fn new() -> Self

pub fn get(&self, name: &str) -> Option<Var>

Return the variable with the given name, if one exists.

pub fn get_or_insert(&mut self, name: &str) -> Var

Get the index associated with a name, or insert a new association.

pub fn insert_wildcard(&mut self) -> Var

Insert a new unnamed wildcard variable.

pub fn get_name(&self, var: Var) -> Option<&str>

Return the associated name of the given variable.

pub fn iter_names(&self) -> impl Iterator<Item = &str>

Returns the names of variables